macro_rules! src {
($($t:tt)*) => { ... };
}Expand description
Create a DebugErr type, which includes information about the locations of the error.
macro_rules! src {
($($t:tt)*) => { ... };
}Create a DebugErr type, which includes information about the locations of the error.